# Release Checklist

1. Tests pass
2. CI passes
3. Build succeeds
4. Clean install succeeds
5. Documentation is up to date
6. Changelog is up to date
7. Tag and release on GitHub
8. Release is published to PyPI

## v0.2.3 - 2025-02-22

1. Tests pass - [X]
2. CI passes
3. Build succeeds - [X]
4. Clean install succeeds
5. Documentation is up to date
6. Changelog is up to date
7. Tag and release on GitHub
8. Release is published to PyPI
